==> react-image-annotate_ns_demo-4.0.70.tgz: package/LazyBrush/BrushPoup.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import CheckIcon from "@mui/icons-material/Check";
import TrashIcon from "@mui/icons-material/Delete";
import WarningAmberIcon from "@mui/icons-material/WarningAmber";
import { makeStyles } from "@mui/styles";
import PreventScrollToParents from "../PreventScrollToParents";
import { Button, // createTheme,
IconButton, // makeStyles,
Paper } from "@mui/material"; // import { ThemeProvider } from "@mui/styles"

import ClickAwayListener from "@mui/material/ClickAwayListener";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import classnames from "classnames";
import React, { useState } from "react";
import CreatableSelect from "react-select/creatable";
import { asMutable } from "seamless-immutable";
import colors from "../colors";
import styles from "../RegionLabel/styles";
var theme = createTheme();
var useStyles = makeStyles(function (theme) {
  return styles;
});

var convertHextoRgb = function convertHextoRgb(color) {
  try {
    var hashRemove = color.replace("#", "");
    var aRgbHex = hashRemove.match(/.{1,2}/g);
    var aRgb = [parseInt(aRgbHex[0], 16), parseInt(aRgbHex[1], 16), parseInt(aRgbHex[2], 16)];
    return aRgb.toString();
  } catch (err) {
    var aRgbHex = "FF0000".match(/.{1,2}/g);
    var aRgb = [parseInt(aRgbHex[0], 16), parseInt(aRgbHex[1], 16), parseInt(aRgbHex[2], 16)];
    return aRgb.toString();
  }
};

function BrushPopup(_ref) {
  var _lines;

  var top = _ref.top,
      left = _ref.left,
      showTags = _ref.showTags,
      lines = _ref.lines,
      lazyBrushClassification = _ref.lazyBrushClassification,
      lazyBrushTags = _ref.lazyBrushTags,
      setLines = _ref.setLines,
      scale = _ref.scale,
      invaild_show = _ref.invaild_show,
      delete_annotation = _ref.delete_annotation,
      setdelete_annotation = _ref.setdelete_annotation,
      annotationType = _ref.annotationType,
      videoTime = _ref.videoTime,
      mouseEvents = _ref.mouseEvents,
      isReadingMode = _ref.isReadingMode;
  var classes = useStyles();

  var _useState = useState(-1),
      _useState2 = _slicedToArray(_useState, 2),
      open = _useState2[0],
      setOpen = _useState2[1];

  var handleClickAway = function handleClickAway() {
    setOpen(-1);
  };

  var popUpPos = function popUpPos(_ref2) {
    var index = _ref2.index,
        top = _ref2.top;
    var labelBoxHeight = open === index ? 170 : 60; // console.log(pbox.y, labelBoxHeight)

    var displayOnTop = top > labelBoxHeight;
    return displayOnTop;
  };

  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(ClickAwayListener, {
    onClickAway: handleClickAway
  }, /*#__PURE__*/React.createElement("div", null, showTags && ((_lines = lines) === null || _lines === void 0 ? void 0 : _lines.map(function (item, index) {
    var _item$popUp3, _item$popUp5, _item$popUp6, _item$popUp6$tags;

    return item.tool === "pen" && /*#__PURE__*/React.createElement("div", {
      style: {
        left: "".concat(item.points[0] * scale, "px"),
        top: "".concat(item.points[1] * scale, "px"),
        position: "absolute",
        width: "200px"
      },
      onMouseDown: function onMouseDown(e) {
        return e.preventDefault();
      },
      onMouseUp: function onMouseUp(e) {
        return e.preventDefault();
      },
      onMouseEnter: function onMouseEnter(e) {
        if (open === index) {
          mouseEvents.onMouseUp(e);
          e.button = 1;
          mouseEvents.onMouseUp(e);
        }
      }
    }, /*#__PURE__*/React.createElement(PreventScrollToParents, {
      key: "brushTags"
    }, /*#__PURE__*/React.createElement(Paper, {
      className: classnames(classes.regionInfo),
      style: _objectSpread({
        zIndex: 20,
        // top: `${19.166664123535156}px`,
        // left: `${197.90878098221688}px`,
        position: "absolute",
        cursor: "pointer",
        border: !invaild_show && lines[index].invalid ? "2px solid red" : null,
        padding: 0
      }, popUpPos({
        index: index,
        top: item.points[1] * scale
      }) ? {
        bottom: 0
      } : {
        top: 0
      })
    }, // document
    //   ?.querySelector(`.${classes.regionInfo}`)
    //   ?.computedStyleMap()
    //   ?.get("opacity")?.value &&
    // document
    //   ?.querySelector(`.${classes.regionInfo}`)
    //   ?.computedStyleMap()
    //   ?.get("opacity")?.value !== 0.5 &&
    open === index ? /*#__PURE__*/React.createElement("div", {
      style: {
        width: 200,
        padding: 10
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        display: "flex",
        flexDirection: "row",
        alignItems: "flex-end"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        display: "flex",
        backgroundColor: colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
          var _item$popUp, _item$popUp$classific;

          return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp = item.popUp) === null || _item$popUp === void 0 ? void 0 : (_item$popUp$classific = _item$popUp.classification) === null || _item$popUp$classific === void 0 ? void 0 : _item$popUp$classific.label);
        })) || 0 % colors.length] || "red",
        color: "#fff",
        padding: 4,
        paddingLeft: 8,
        paddingRight: 8,
        borderRadius: 4,
        fontWeight: "bold",
        textShadow: "0px 0px 5px rgba(0,0,0,0.4)"
      }
    }, "Brush"), /*#__PURE__*/React.createElement("div", {
      style: {
        flexGrow: 1
      }
    }), /*#__PURE__*/React.createElement(IconButton, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(lines);

        linessave.splice(index, 1);
        lines = linessave;
        setLines(linessave);

        var arr = _toConsumableArray(delete_annotation);

        arr.push(item);
        setdelete_annotation(arr);
      },
      tabIndex: -1,
      style: {
        width: 22,
        height: 22
      },
      size: "small",
      variant: "outlined"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      style: {
        marginTop: -8,
        width: 16,
        height: 16
      }
    })), invaild_show && /*#__PURE__*/React.createElement(IconButton, {
      onClick: function onClick() {
        var linessave = _toConsumableArray(lines);

        lines[index].invalid = lines[index].invalid ? false : true;
        setLines(linessave);
      },
      tabIndex: -1,
      style: {
        width: 22,
        height: 22
      },
      size: "small",
      variant: "outlined"
    }, /*#__PURE__*/React.createElement(WarningAmberIcon, {
      style: {
        color: lines[index].invalid ? "#faad14" : "grey",
        marginTop: -8,
        width: 16,
        height: 16
      } // color={
      //   lines[index].invalid ? "primary" : "secondary"
      // }

    }))), /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 6
      }
    }, /*#__PURE__*/React.createElement(CreatableSelect // menuShouldBlockScroll={true}
    , {
      menuPosition: "fixed",
      menuPlacement: "auto",
      placeholder: "Classification",
      onChange: function onChange(o, actionMeta) {
        var linessave = _toConsumableArray(lines);

        lines[index].popUp.classification = o;
        lines[index].color = "rgba(".concat(convertHextoRgb(colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
          var _item$popUp2, _item$popUp2$classifi;

          return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp2 = item.popUp) === null || _item$popUp2 === void 0 ? void 0 : (_item$popUp2$classifi = _item$popUp2.classification) === null || _item$popUp2$classifi === void 0 ? void 0 : _item$popUp2$classifi.label);
        })) || 0 % colors.length] || "#FF0000"), ",0.5)");
        setLines(linessave);
      },
      value: lines[index].popUp.classification,
      options: asMutable(lazyBrushClassification.map(function (c) {
        return {
          value: c,
          label: c
        };
      }))
    })), /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 4
      }
    }, /*#__PURE__*/React.createElement(CreatableSelect // menuShouldBlockScroll={true}
    , {
      menuPosition: "fixed",
      menuPlacement: "auto" // menuIsOpen={true}
      ,
      value: lines[index].popUp.tags,
      placeholder: "Tags",
      onChange: function onChange(o, actionMeta) {
        var _lines2, _lines2$index, _lines2$index$popUp, _lines2$index$popUp$t;

        var linessave = _toConsumableArray(lines);

        lines[index].popUp.tags = o;
        lines[index].tag_count = (_lines2 = lines) === null || _lines2 === void 0 ? void 0 : (_lines2$index = _lines2[index]) === null || _lines2$index === void 0 ? void 0 : (_lines2$index$popUp = _lines2$index.popUp) === null || _lines2$index$popUp === void 0 ? void 0 : (_lines2$index$popUp$t = _lines2$index$popUp.tags) === null || _lines2$index$popUp$t === void 0 ? void 0 : _lines2$index$popUp$t.length;
        setLines(linessave);
      },
      isMulti: true,
      options: asMutable(lazyBrushTags.map(function (c) {
        return {
          value: c,
          label: c
        };
      }))
    })), /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 4,
        display: "flex"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        flexGrow: 1
      }
    }), /*#__PURE__*/React.createElement(Button, {
      onClick: function onClick() {
        // let linessave = [...lines]
        // lines[index].popUp.open = false
        // setLines(linessave)
        setOpen(-1);
      },
      size: "small",
      variant: "contained",
      color: "primary"
    }, /*#__PURE__*/React.createElement(CheckIcon, null)))) : /*#__PURE__*/React.createElement("div", {
      style: {
        padding: 8
      },
      onClick: function onClick() {
        // let linessave = [...lines]
        // lines[index].popUp.open = true
        // let i = 0
        // for (i = 0; i < lines?.length; i++) {
        //   if (i !== index) {
        //     lines[i].popUp.open = false
        //   }
        // }
        // setLines(linessave)
        !isReadingMode && setOpen(index);
      }
    }, (item === null || item === void 0 ? void 0 : (_item$popUp3 = item.popUp) === null || _item$popUp3 === void 0 ? void 0 : _item$popUp3.classification) && /*#__PURE__*/React.createElement("div", {
      className: "name",
      style: {
        display: "flex",
        justifyContent: "flex-start",
        alignItems: "center",
        width: "max-content"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        backgroundColor: colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
          var _item$popUp4;

          return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp4 = item.popUp) === null || _item$popUp4 === void 0 ? void 0 : _item$popUp4.classification.label);
        })) % colors.length],
        width: "10px",
        height: "10px",
        boxShadow: "0px 0px 2px rgb(0 0 0 / 40%)",
        marginRight: "4px",
        borderRadius: "5px"
      }
    }), /*#__PURE__*/React.createElement("span", null, item === null || item === void 0 ? void 0 : (_item$popUp5 = item.popUp) === null || _item$popUp5 === void 0 ? void 0 : _item$popUp5.classification.label)), /*#__PURE__*/React.createElement("div", {
      className: "tags"
    }, item === null || item === void 0 ? void 0 : (_item$popUp6 = item.popUp) === null || _item$popUp6 === void 0 ? void 0 : (_item$popUp6$tags = _item$popUp6.tags) === null || _item$popUp6$tags === void 0 ? void 0 : _item$popUp6$tags.map(function (t) {
      return /*#__PURE__*/React.createElement("div", {
        className: "tag"
      }, "".concat(t.label));
    }))))));
  })))));
}

export default BrushPopup;

==> react-image-annotate_ns_demo-4.0.82.tgz: package/LazyBrush/BrushPoup.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import CheckIcon from "@mui/icons-material/Check";
import TrashIcon from "@mui/icons-material/Delete";
import WarningAmberIcon from "@mui/icons-material/WarningAmber";
import { makeStyles } from "@mui/styles";
import PreventScrollToParents from "../PreventScrollToParents";
import { Button, // createTheme,
IconButton, // makeStyles,
Paper } from "@mui/material"; // import { ThemeProvider } from "@mui/styles"

import ClickAwayListener from "@mui/material/ClickAwayListener";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import classnames from "classnames";
import React, { useState } from "react";
import CreatableSelect from "react-select/creatable";
import { asMutable } from "seamless-immutable";
import colors from "../colors";
import styles from "../RegionLabel/styles";
var theme = createTheme();
var useStyles = makeStyles(function (theme) {
  return styles;
});

var convertHextoRgb = function convertHextoRgb(color) {
  try {
    var hashRemove = color.replace("#", "");
    var aRgbHex = hashRemove.match(/.{1,2}/g);
    var aRgb = [parseInt(aRgbHex[0], 16), parseInt(aRgbHex[1], 16), parseInt(aRgbHex[2], 16)];
    return aRgb.toString();
  } catch (err) {
    var aRgbHex = "FF0000".match(/.{1,2}/g);
    var aRgb = [parseInt(aRgbHex[0], 16), parseInt(aRgbHex[1], 16), parseInt(aRgbHex[2], 16)];
    return aRgb.toString();
  }
};

function BrushPopup(_ref) {
  var top = _ref.top,
      left = _ref.left,
      showTags = _ref.showTags,
      lines = _ref.lines,
      lazyBrushClassification = _ref.lazyBrushClassification,
      lazyBrushTags = _ref.lazyBrushTags,
      setLines = _ref.setLines,
      scale = _ref.scale,
      invaild_show = _ref.invaild_show,
      delete_annotation = _ref.delete_annotation,
      setdelete_annotation = _ref.setdelete_annotation,
      annotationType = _ref.annotationType,
      videoTime = _ref.videoTime,
      mouseEvents = _ref.mouseEvents,
      isReadingMode = _ref.isReadingMode,
      setTegged = _ref.setTegged,
      setLoacal_id = _ref.setLoacal_id;

  var getRandomId = function getRandomId() {
    return Math.random().toString().split(".")[1];
  };

  var classes = useStyles();

  var _useState = useState(-1),
      _useState2 = _slicedToArray(_useState, 2),
      open = _useState2[0],
      setOpen = _useState2[1];

  var handleClickAway = function handleClickAway() {
    setOpen(-1);
  };

  var popUpPos = function popUpPos(_ref2) {
    var index = _ref2.index,
        top = _ref2.top;
    var labelBoxHeight = open === index ? 170 : 60; // console.log(pbox.y, labelBoxHeight)

    var displayOnTop = top > labelBoxHeight;
    return displayOnTop;
  };

  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(ClickAwayListener, {
    onClickAway: handleClickAway
  }, /*#__PURE__*/React.createElement("div", null, showTags && (lines === null || lines === void 0 ? void 0 : lines.map(function (item, index) {
    var _item$popUp3, _item$popUp5, _item$popUp6, _item$popUp6$tags;

    return item.isPopupShow === true && item.tool === "pen" && /*#__PURE__*/React.createElement("div", {
      style: {
        left: "".concat(item.points[0] * scale, "px"),
        top: "".concat(item.points[1] * scale, "px"),
        position: "absolute",
        width: "200px"
      },
      onMouseDown: function onMouseDown(e) {
        return e.preventDefault();
      },
      onMouseUp: function onMouseUp(e) {
        return e.preventDefault();
      },
      onMouseEnter: function onMouseEnter(e) {
        if (open === index) {
          mouseEvents.onMouseUp(e);
          e.button = 1;
          mouseEvents.onMouseUp(e);
        }
      }
    }, /*#__PURE__*/React.createElement(PreventScrollToParents, {
      key: "brushTags"
    }, /*#__PURE__*/React.createElement(Paper, {
      className: classnames(classes.regionInfo),
      style: _objectSpread({
        zIndex: 20,
        // top: `${19.166664123535156}px`,
        // left: `${197.90878098221688}px`,
        position: "absolute",
        cursor: "pointer",
        border: !invaild_show && lines[index].invalid ? "2px solid red" : null,
        padding: 0
      }, popUpPos({
        index: index,
        top: item.points[1] * scale
      }) ? {
        bottom: 0
      } : {
        top: 0
      })
    }, open === index ? /*#__PURE__*/React.createElement("div", {
      style: {
        width: 200,
        padding: 10
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        display: "flex",
        flexDirection: "row",
        alignItems: "flex-end"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        display: "flex",
        backgroundColor: colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
          var _item$popUp, _item$popUp$classific;

          return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp = item.popUp) === null || _item$popUp === void 0 ? void 0 : (_item$popUp$classific = _item$popUp.classification) === null || _item$popUp$classific === void 0 ? void 0 : _item$popUp$classific.label);
        })) || 0 % colors.length] || "red",
        color: "#fff",
        padding: 4,
        paddingLeft: 8,
        paddingRight: 8,
        borderRadius: 4,
        fontWeight: "bold",
        textShadow: "0px 0px 5px rgba(0,0,0,0.4)"
      }
    }, "Brush"), /*#__PURE__*/React.createElement("div", {
      style: {
        flexGrow: 1
      }
    }), /*#__PURE__*/React.createElement(IconButton, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(lines);

        var filter_arr = linessave.filter(function (filters) {
          return filters.id !== item.id && filters;
        });
        setLines(filter_arr);

        var arr = _toConsumableArray(delete_annotation);

        var delete_arr = linessave.filter(function (filter) {
          return filter.id === item.id && filter;
        });
        arr.push(delete_arr);
        setdelete_annotation(arr);
      },
      tabIndex: -1,
      style: {
        width: 22,
        height: 22
      },
      size: "small",
      variant: "outlined"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      style: {
        marginTop: -8,
        width: 16,
        height: 16
      }
    })), invaild_show && /*#__PURE__*/React.createElement(IconButton, {
      onClick: function onClick() {
        var linessave = _toConsumableArray(lines);

        var find_same_id = linessave === null || linessave === void 0 ? void 0 : linessave.map(function (items, itemIndex) {
          if (items.id === item.id) {
            lines[itemIndex].invalid = lines[itemIndex].invalid ? false : true;
          }

          return linessave;
        });
        setLines(linessave);
      },
      tabIndex: -1,
      style: {
        width: 22,
        height: 22
      },
      size: "small",
      variant: "outlined"
    }, /*#__PURE__*/React.createElement(WarningAmberIcon, {
      style: {
        color: lines[index].invalid ? "#faad14" : "grey",
        marginTop: -8,
        width: 16,
        height: 16
      }
    }))), /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 6
      }
    }, /*#__PURE__*/React.createElement(CreatableSelect // menuShouldBlockScroll={true}
    , {
      menuPosition: "fixed",
      menuPlacement: "auto",
      placeholder: "Classification",
      onChange: function onChange(o, actionMeta) {
        var linessave = _toConsumableArray(lines);

        var find_same_id = linessave === null || linessave === void 0 ? void 0 : linessave.map(function (items, itemIndex) {
          if (items.id === item.id) {
            lines[itemIndex].popUp.classification = o;
            lines[itemIndex].color = "rgba(".concat(convertHextoRgb(colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
              var _item$popUp2, _item$popUp2$classifi;

              return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp2 = item.popUp) === null || _item$popUp2 === void 0 ? void 0 : (_item$popUp2$classifi = _item$popUp2.classification) === null || _item$popUp2$classifi === void 0 ? void 0 : _item$popUp2$classifi.label);
            })) || 0 % colors.length] || "#FF0000"), ",0.5)");
          }

          return linessave;
        });
        setLines(linessave);
      },
      value: lines[index].popUp.classification,
      options: asMutable(lazyBrushClassification.map(function (c) {
        return {
          value: c,
          label: c
        };
      }))
    })), /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 4
      }
    }, /*#__PURE__*/React.createElement(CreatableSelect // menuShouldBlockScroll={true}
    , {
      menuPosition: "fixed",
      menuPlacement: "auto" // menuIsOpen={true}
      ,
      value: lines[index].popUp.tags,
      placeholder: "Tags",
      onChange: function onChange(o, actionMeta) {
        var linessave = _toConsumableArray(lines);

        var find_same_id = linessave === null || linessave === void 0 ? void 0 : linessave.map(function (items, itemIndex) {
          if (items.id === item.id) {
            var _lines$itemIndex, _lines$itemIndex$popU, _lines$itemIndex$popU2;

            lines[itemIndex].popUp.tags = o;
            lines[itemIndex].tag_count = lines === null || lines === void 0 ? void 0 : (_lines$itemIndex = lines[itemIndex]) === null || _lines$itemIndex === void 0 ? void 0 : (_lines$itemIndex$popU = _lines$itemIndex.popUp) === null || _lines$itemIndex$popU === void 0 ? void 0 : (_lines$itemIndex$popU2 = _lines$itemIndex$popU.tags) === null || _lines$itemIndex$popU2 === void 0 ? void 0 : _lines$itemIndex$popU2.length;
          }

          return linessave;
        });
        setLines(linessave);
        setLines(linessave);
        setTegged(true);
        setLoacal_id(getRandomId());
      },
      isMulti: true,
      options: asMutable(lazyBrushTags.map(function (c) {
        return {
          value: c,
          label: c
        };
      }))
    })), /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 4,
        display: "flex"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        flexGrow: 1
      }
    }), /*#__PURE__*/React.createElement(Button, {
      onClick: function onClick() {
        setOpen(-1);
      },
      size: "small",
      variant: "contained",
      color: "primary"
    }, /*#__PURE__*/React.createElement(CheckIcon, null)))) : /*#__PURE__*/React.createElement("div", {
      style: {
        padding: 8
      },
      onClick: function onClick() {
        !isReadingMode && setOpen(index);
      }
    }, (item === null || item === void 0 ? void 0 : (_item$popUp3 = item.popUp) === null || _item$popUp3 === void 0 ? void 0 : _item$popUp3.classification) && /*#__PURE__*/React.createElement("div", {
      className: "name",
      style: {
        display: "flex",
        justifyContent: "flex-start",
        alignItems: "center",
        width: "max-content"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        backgroundColor: colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
          var _item$popUp4;

          return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp4 = item.popUp) === null || _item$popUp4 === void 0 ? void 0 : _item$popUp4.classification.label);
        })) % colors.length],
        width: "10px",
        height: "10px",
        boxShadow: "0px 0px 2px rgb(0 0 0 / 40%)",
        marginRight: "4px",
        borderRadius: "5px"
      }
    }), /*#__PURE__*/React.createElement("span", null, item === null || item === void 0 ? void 0 : (_item$popUp5 = item.popUp) === null || _item$popUp5 === void 0 ? void 0 : _item$popUp5.classification.label)), /*#__PURE__*/React.createElement("div", {
      className: "tags"
    }, item === null || item === void 0 ? void 0 : (_item$popUp6 = item.popUp) === null || _item$popUp6 === void 0 ? void 0 : (_item$popUp6$tags = _item$popUp6.tags) === null || _item$popUp6$tags === void 0 ? void 0 : _item$popUp6$tags.map(function (t) {
      return /*#__PURE__*/React.createElement("div", {
        className: "tag"
      }, "".concat(t.label));
    }))))));
  })))));
}

export default BrushPopup;
